FlutterPaymentezSDK class

Constructors

FlutterPaymentezSDK({String serverApplicationCode = '', String serverAppKey = '', String clientApplicationCode = '', String clientAppKey = '', bool isProd = false, bool isPCI = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCard(AddCardRequest newCard) Future<(AddCardResponse?, PaymentezError?)>
debit(PayRequest payRequest) Future<(PayResponse?, PaymentezError?)>
debitCC(PayPCIRequest payPCIRequest) Future<(PayResponse?, PaymentezError?)>
deleteCard(DeleteCardRequest deleteCardRequest) Future<(DeleteCardResponse?, PaymentezError?)>
getAllCards(String userID) Future<(CardsResponse?, PaymentezError?)>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refund(RefundRequest refundRequest) Future<(RefundResponse?, PaymentezError?)>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited