InstallmentsType enum
Values
- type0 → const InstallmentsType
-
const InstallmentsType(value: 0, description: 'Revolving credit (rotativo)') - type1 → const InstallmentsType
-
const InstallmentsType(value: 1, description: 'Revolving and deferred without interest (The bank will pay ' 'to the commerce the installment, month by month)') - type2 → const InstallmentsType
-
const InstallmentsType(value: 2, description: 'Deferred with interest') - type3 → const InstallmentsType
-
const InstallmentsType(value: 3, description: 'Deferred without interest') - type7 → const InstallmentsType
-
const InstallmentsType(value: 7, description: 'Deferred with interest and months of grace') - type6 → const InstallmentsType
-
const InstallmentsType(value: 6, description: 'Deferred without interest pay month by month. (*)') - type9 → const InstallmentsType
-
const InstallmentsType(value: 9, description: 'Deferred without interest and months of grace') - type10 → const InstallmentsType
-
const InstallmentsType(value: 10, description: 'Deferred without interest promotion bimonthly. (*)') - type21 → const InstallmentsType
-
const InstallmentsType(value: 21, description: 'For Diners Club exclusive, deferred with and without interest') - type22 → const InstallmentsType
-
const InstallmentsType(value: 22, description: 'For Diners Club exclusive, deferred with and without interest') - type30 → const InstallmentsType
-
const InstallmentsType(value: 30, description: 'Deferred with interest pay month by month. (*)') - type50 → const InstallmentsType
-
const InstallmentsType(value: 50, description: 'Deferred without interest promotions (Supermaxi). (*)') - type51 → const InstallmentsType
-
const InstallmentsType(value: 51, description: 'Deferred with interest (Cuota fácil). (*)') - type52 → const InstallmentsType
-
const InstallmentsType(value: 52, description: 'Without interest (Rendecion Produmillas). (*)') - type53 → const InstallmentsType
-
const InstallmentsType(value: 53, description: 'Without interest sale with promotions. (*)') - type70 → const InstallmentsType
-
const InstallmentsType(value: 70, description: 'Deferred special without interest. (*)') - type72 → const InstallmentsType
-
const InstallmentsType(value: 72, description: 'Credit without interest (cte smax). (*)') - type73 → const InstallmentsType
-
const InstallmentsType(value: 73, description: 'Special credit without interest (smax). (*)') - type74 → const InstallmentsType
-
const InstallmentsType(value: 74, description: 'Prepay without interest (smax). (*)') - type75 → const InstallmentsType
-
const InstallmentsType(value: 75, description: 'Deffered credit without interest (smax). (*)') - type90 → const InstallmentsType
-
const InstallmentsType(value: 90, description: 'Without interest with months of grace (Supermaxi). (*)')
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
InstallmentsType> - A constant List of the values in this enum, in order of their declaration.